@@ -19,7 +19,7 @@ AtteanX::Store::LDF - Linked Data Fragment RDF store
     use AtteanX::Store::LDF;
 
     my $uri   = 'http://fragments.dbpedia.org/2014/en';
-    my $store = Attean->get_store('LDF')->new(endpoint_url => $uri);
+    my $store = Attean->get_store('LDF')->new(start_url => $uri);
 
     my $iter = $store->get_triples(undef,undef,literal("Albert Einstein"));
 
@@ -44,14 +44,15 @@ use warnings;
 
 package AtteanX::Store::LDF;
 
-our $VERSION = '0.005_01';
+our $VERSION = '0.005_02';
 
 use Moo;
 use Attean::API::Store;
 use Type::Tiny::Role;
-use Types::Standard qw(Str);
+use Types::URI -all;
 use RDF::LDF;
 use namespace::clean;
+use Carp;
 
 with 'Attean::API::TripleStore', 'MooX::Log::Any';
 
@@ -63,18 +64,25 @@ L<Attean::API::TripleStore> class.
 
 =over 4
 
-=item new( endpoint_url => $endpoint_url )
+=item new( start_url => $start_url )
 
-Returns a new LDF-backed storage object.
+Returns a new LDF-backed storage object. The required C<start_url>
+argument is a URL pointing at any Linked Data Fragment. The attribure
+will be coerced, so it can be a string, a URI object, etc.
 
 =cut
 
-has endpoint_url => (is => 'ro', isa => Str, required => 1);
+has start_url => (is => 'ro', isa => Uri, coerce => 1, required => 1);
+has endpoint_url => (is => 'ro', lazy => 1, builder => '_croak_on_endpoint');
 has ldf => (is => 'ro', lazy => 1, builder => '_ldf');
 
+sub _croak_on_endpoint {
+	Carp::croak "endpoint_url has been deprecated, use start_url instead";
+}
+
 sub _ldf {
     my $self = shift;
-    RDF::LDF->new(url => $self->endpoint_url);
+    RDF::LDF->new(url => $self->start_url->as_string);
 }
 
 sub _term_as_string {
